@@ -1,7 +1,7 @@
 # This is file ../spam/R/plotting.R
 # This file is part of the spam package, 
 #      http://www.math.uzh.ch/furrer/software/spam/
-# written and maintained by Reinhard Furrer.
+# by Reinhard Furrer [aut, cre], Florian Gerber [ctb]
      
 
 
@@ -16,7 +16,7 @@ if(! exists(".bincode", envir = .BaseNamespaceEnv))
     .bincode <- function(v, breaks, ...) {
         .C("bincode", as.double(v), length(v), as.double(breaks),
            length(breaks), code = integer(length(v)), as.logical(TRUE),
-           as.logical(TRUE), nok = TRUE, NAOK = TRUE, DUP = FALSE,
+           as.logical(TRUE), nok = TRUE, NAOK = TRUE, 
            PACKAGE = "base")$code
     }
 
