@@ -6,11 +6,9 @@ C       c("euclidean", "maximum", "minkowski", "greatcircle")
 C     
 c     In case we need the distance matrix between x and x, then the
 c     following parameters are used as well:
-c     if diag = 1 include a potentional diagonal zero value
-c        diag =-1 always subject to > eps
 c     if part=-1, lower tri, part=0 the entire matrix
 c        part= 1, upper tri only.
-c     only values between eps and eta are considered.
+c     only values smaller than eta are considered.
 c     p power for minkowski
 
 
@@ -34,8 +32,8 @@ c     p power for minkowski
 
 
       subroutine closestdist( ncol, x,nrowx, y, nrowy,
-     &    diag, part, p, method, 
-     &    eps, eta, colindices, rowpointers, entries, nnz, iflag)
+     &    part, p, method, 
+     &    eta, colindices, rowpointers, entries, nnz, iflag)
 
       implicit none
       
@@ -43,10 +41,10 @@ c     p power for minkowski
       double precision euclid, minkowski
       external euclid, minkowski
 
-      integer ncol,nrowx, nrowy, nnz, method,  diag, part,  iflag
+      integer ncol,nrowx, nrowy, nnz, method,  part,  iflag
       integer colindices(nnz), rowpointers(nrowx+1)
       double precision p, x(nrowx,ncol),y(nrowy,ncol) 
-      double precision eps, eta, entries(nnz)
+      double precision eta, entries(nnz)
       
 
 
@@ -54,24 +52,24 @@ c     p power for minkowski
       if (method.eq.1) then
          p=2.0
          call closestEdistXY( ncol, x,nrowx, y, nrowy,
-     &        diag, part, p, euclid,
-     &        eps, eta, colindices, rowpointers, entries, nnz, iflag)
+     &        part, p, euclid,
+     &        eta, colindices, rowpointers, entries, nnz, iflag)
       endif
       if (method.eq.2) then
          p=1.0
          call closestMAXdistXY( ncol, x,nrowx, y, nrowy,
-     &        diag, part, 
-     &        eps, eta, colindices, rowpointers, entries, nnz, iflag)
+     &        part, 
+     &        eta, colindices, rowpointers, entries, nnz, iflag)
       endif
       if (method.eq.3) then
          call closestEdistXY( ncol, x,nrowx, y, nrowy,
-     &        diag, part, p, minkowski,
-     &        eps, eta, colindices, rowpointers, entries, nnz, iflag)
+     &        part, p, minkowski,
+     &        eta, colindices, rowpointers, entries, nnz, iflag)
       endif
       if (method.eq.4) then
          call closestGCdistXY( x,nrowx, y, nrowy,
-     &        diag, part, p,
-     &        eps, eta, colindices, rowpointers, entries, nnz, iflag)
+     &        part, p,
+     &        eta, colindices, rowpointers, entries, nnz, iflag)
       endif
       return
       end
@@ -79,25 +77,24 @@ c     p power for minkowski
 
       
       subroutine closestEdistXY( ncol, x,xnrow, y, ynrow,
-     &    diag, part, p, distfcn,
-     &    eps, eta, colindices, rowpointers, entries, nnz, iflag)
+     &    part, p, distfcn,
+     &    eta, colindices, rowpointers, entries, nnz, iflag)
 
       implicit none
       
       double precision distfcn
       external distfcn
 
-      integer ncol,xnrow, ynrow, nnz,  diag, part,iflag
+      integer ncol,xnrow, ynrow, nnz,  part,iflag
       integer colindices(nnz),rowpointers(xnrow+1)
       double precision p,x(xnrow,ncol), y(ynrow,ncol)
-      double precision eps, eta, entries(nnz)
+      double precision eta, entries(nnz)
       
 c     local variables
-      integer jja, i,j,k, ifrom,ito, jfrom, jto
-      double precision epsp,etap, tmp,pinv
+      integer jja, i,j,k, jfrom, jto
+      double precision etap, tmp,pinv
       
 
-      epsp=eps**p
       etap=eta**p
       pinv=1/p
       
@@ -108,7 +105,7 @@ c     local variables
       jto = ynrow
       
       
-c cycle over all rows of x (independent of part and diag!)       
+c cycle over all rows of x (independent of part)       
       
       do i= 1,xnrow
          
@@ -128,20 +125,6 @@ c Start calculating the distance (until delta is exceeded)
                if( tmp.gt.etap) goto 10
             enddo
 c Delta is not exceeded. 
-c If we need to do not include the diagonal (diag==-1)
-c    eps < tmp < delta
-c If we do include the diagonal  (diag==1),  
-c    eps < tmp < delta for i=/=j only
- 
-            if (diag.eq.-1) then
-               if (tmp.lt.epsp) goto 10
-            else
-               if (i.ne.j) then
-                  if (tmp.lt.epsp) goto 10
-               endif
-            endif
-
-c     (i,j) has a distance between eps and eta.
             
 c     in case nnz was too small, recall line to get a better estimate
             if( jja .gt. nnz) then
@@ -177,18 +160,18 @@ c     in case nnz was too small, recall line to get a better estimate
       end
       
       subroutine closestMAXdistXY( ncol, x,xnrow, y, ynrow,
-     &    diag, part, 
-     &    eps, eta, colindices, rowpointers, entries, nnz, iflag)
+     &    part, 
+     &    eta, colindices, rowpointers, entries, nnz, iflag)
 
       implicit none
       
-      integer ncol,xnrow, ynrow, nnz,  diag, part,iflag
+      integer ncol,xnrow, ynrow, nnz,  part,iflag
       integer colindices(nnz),rowpointers(xnrow+1)
       double precision x(xnrow,ncol), y(ynrow,ncol)
-      double precision eps, eta, entries(nnz)
+      double precision eta, entries(nnz)
       
 c     local variables
-      integer jja, i,j,k, ifrom,ito, jfrom, jto
+      integer jja, i,j,k, jfrom, jto
       double precision  tmp
       
 
@@ -219,20 +202,7 @@ c Start calculating the distance
             enddo
 
 c Delta is not exceeded. 
-c If we need to do not include the diagonal (diag==-1)
-c    eps < tmp < delta
-c If we do include the diagonal (diag==1),  
-c    eps < tmp < delta for i=/=j only
- 
-            if (diag.eq.-1) then
-               if (tmp.lt.eps) goto 10
-            else
-               if (i.ne.j) then
-                  if (tmp.lt.eps) goto 10
-               endif
-            endif
-
-c     (i,j) has a distance between eps and eta.
+c     (i,j) has a distance smaller than eta.
       
                     
             
@@ -264,19 +234,19 @@ c     in case nnz was too small, recall line to get a better estimate
 
 
       subroutine closestGCdistXY( x,nx, y, ny,
-     &    diag, part,p, 
-     &    eps, eta, colindices, rowpointers, entries, nnz, iflag)
+     &    part,p, 
+     &    eta, colindices, rowpointers, entries, nnz, iflag)
 
       implicit none
       
       integer nx, ny, nnz, colindices(nnz),rowpointers(nx+1)
-      integer diag, part, iflag
-      double precision x(nx,2), y(ny,2), p, eps, eta, entries(nnz)
+      integer part, iflag
+      double precision x(nx,2), y(ny,2), p, eta, entries(nnz)
       
 c     local variables
       logical equi
-      integer jja, i,j,k, ifrom,ito, jfrom, jto
-      double precision etap, epsp,tmp, rad, tmp1, tmp2
+      integer jja, i,j, jfrom, jto
+      double precision etap, tmp, rad, tmp1, tmp2
       double precision scy12(ny), ccy12(ny), sy2(ny)
       double precision scx12,     ccx12,     sx2
       
@@ -285,9 +255,9 @@ c     local variables
 
 c     Great savings if we know that x=y. This can be done by
 c     multiplying diag by two.
-      if (abs(diag).gt.1) then
+      if (p .lt. 0) then
          equi=.TRUE.
-         diag=diag/2
+         p=-p
       else 
          equi= .FALSE. 
       endif
@@ -295,7 +265,6 @@ c     multiplying diag by two.
       jja=1
        
       etap=cos(eta*rad)
-      epsp=cos(eps*rad)
       rowpointers(1)=1
       jfrom = 1
       jto = ny
@@ -325,43 +294,32 @@ c     x2 is missing if equi=.TRUE. and we reuse the y stuff
             scx12=dsin(tmp1)*dcos(tmp2)
             sx2=dsin(tmp2)
          endif 
-
+         
          if (part .lt. 0) then
             jto = i
          endif
          if (part .gt. 0) then
             jfrom = i
          endif
-       
+         
          do 10 j = jfrom,jto
-
-
-c Start calculating the distance 
+            
+            
+c     Start calculating the distance 
             tmp = ccx12 * ccy12(j) + scx12 * scy12(j)  + sx2*sy2(j)
+
+            
             if (tmp .lt. etap) goto 10
-            
-            
-c Delta is not exceeded. 
-c If we do not need to include the diagonal (diag==-1)
-c    eps < tmp < delta
-c If we do include the diagonal (diag==1),  
-c    eps < tmp < delta for i=/=j only
- 
-            if (diag.eq.-1) then
-               if (tmp.ge.epsp) goto 10
+c     Delta is not exceeded. 
+
+c     Due to numerical instabilities, we need the following... 0.15-2:
+            if  (tmp .ge. 1) then
+               tmp = 0.0
             else
-               if (i.ne.j) then
-                  if (tmp.ge.epsp) goto 10
-               else
-c Due to numerical instabilities, we need the following... 0.15-2:
-                  if  (tmp .ge. 1) tmp = 1.0
-               endif
+               tmp = dacos( tmp)
             endif
 
-            tmp = dacos( tmp)
-
-
-c     (i,j) has a distance between eps and eta.
+c     (i,j) has a distance smaller than eta.
             
 c     In case nnz was too small, recall line to get a better estimate
             if( jja .gt. nnz) then
